import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCPeerID(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(MultipeerConnectivity.MCPeerID, objc.objc_class)



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCAdvertiserAssistant(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(
            MultipeerConnectivity.MCAdvertiserAssistant, objc.objc_class
        )

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("MCAdvertiserAssistantDelegate"), objc.formal_protocol
        )



"""
Python mapping for the MultipeerConnectivity framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from MultipeerConnectivity import _metadata
from MultipeerConnectivity import _MultipeerConnectivity

sys.modules["MultipeerConnectivity"] = mod = objc.ObjCLazyModule(
    "MultipeerConnectivity",
    "com.apple.MultipeerConnectivity",
    objc.pathForFramework("/System/Library/Frameworks/MultipeerConnectivity.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_MultipeerConnectivity, Foundation),
)


del sys.modules["MultipeerConnectivity._metadata"]
del sys.modules["MultipeerConnectivity._MultipeerConnectivity"]



import objc
from PyObjCTools.TestSupport import TestCase, min_os_level
import MultipeerConnectivity


class TestMCBrowserViewControllerHelper(MultipeerConnectivity.NSObject):
    def browserViewController_shouldPresentNearbyPeer_withDiscoveryInfo_(
        self, vc, p, i
    ):
        return 1


class TestMCBrowserViewController(TestCase):
    @min_os_level("10.10")
    def testClasses(self):
        self.assertIsInstance(
            MultipeerConnectivity.MCBrowserViewController, objc.objc_class
        )

    @min_os_level("10.10")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("MCBrowserViewControllerDelegate"), objc.formal_protocol
        )

        self.assertResultIsBOOL(
            TestMCBrowserViewControllerHelper.browserViewController_shouldPresentNearbyPeer_withDiscoveryInfo_
        )
